#!/usr/bin/ksh
####################################################################################################
# Install script for FireScope Agent for AIX
####################################################################################################
VERSION=2.0.11
####################################################################################################
# functions
####################################################################################################

	############################################################################################
	# FireScope Agent Help Function
	############################################################################################
	show_help () {
		HELPUSAGE="$INSTALLER -A XXX.XXX.XXX.XXX [ options ]"
		HELPAPPLIANCE="-A : Appliance IP or DNS name. Usage FireScope_Agent_Installer.sh -a XXX.XXX.XXX.XXX(Required - IP or DNS Name to FireScope Appliance.)"
		HELPBASEINTALLPATH="-b : InstallPath - Path to install the FireScope Agent. default - /opt/firescope"
		HELPREMOTECOMMAND="-c : RemoteCommand - Allows the FireScope Appliance to send commands to the agent to execute. default 0 (Valid 1 on - 0 off)"
		HELPDISABLEACTIVE="-d : DisableActive - Disables Active checks. default 0 (Valid 1 on - 0 off)"
		HELPHELP="-h : Help - Displays this help file"
		HELPHOSTNAME="-H : CINAME - Hostname or name used to ID the system in the FireScope Appliance. Must match for AgentRemote to work properly."
		HELPJAVAPATH="-j : Path to the Java installation to be used (/usr/java/jre1.6.0_21/bin/java)"
		HELPMANAGERPORT="-m : ManagerPort - Port used by the agent manager to receive data from the FireScope Appliance. default - 8044 (Valid 1-65535)"
		HELPSTORECOUNT="-n : Storecount - Used in Store&Foward mode. The number of metrics stored before sending. default - 100 (valid 10-200)"
		HELPAGENTPORT="-p : AgentPort - Port used by the agent to receive data from the FireScope Appliance. default - 8042 (Valid 1-65535)"
		HELPREALTIME="-s : Realtime - Sets the FireScope Agent to realtime mode. default - 1 (Valid 1-Realtime 0-Store&Forward)"
		HELPSTORETIME="-t : Storetime - Used in Store&Foward mode. The amount of time in seconds that the agent will cache metrics before sending. default - 300 (Valid 30 - 600)"
		HELPUPGRADE="-u : Upgrade - Used to upgrade a legacy flex_agent.conf to a flex_agent_posix.xml"
		HELPEXAMPLE="e.g. $INSTALLER -A 10.0.2.40 -b /opt/firescope -p 8042 -c 1 -H myserver -s 1 -t 200 -n 400"
		SHOW_HELP="$HELPUSAGE\n\t$HELPAPPLIANCE\n\t$HELPBASEINTALLPATH\n\t$HELPREMOTECOMMAND\n\t$HELPDISABLEACTIVE\n\t$HELPHELP\n\t$HELPHOSTNAME\n\t$HELPMANAGERPORT\n\t$HELPSTORECOUNT\n\t$HELPAGENTPORT\n\t$HELPREALTIME\n\t$HELPSTORETIME\n\t$HELPUPGRADE\n\t$HELPEXAMPLE"
		echo "$SHOW_HELP"
		exit 1
	}
	############################################################################################
	# Resolve the location executables
	############################################################################################
	resolve_Executables () {
		#-----------------------------------------------------------------
		# Resolve the location of the 'ps' command
		#-----------------------------------------------------------------
		PSEXE="/usr/bin/ps"
		if [ ! -x "$PSEXE" ]
		then
			PSEXE="/bin/ps"
			if [ ! -x "$PSEXE" ]
			then
				echo "Unable to locate 'ps'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
			DATE=`/bin/date` 
		else
			DATE=`/usr/bin/date` 
		fi
		PSKEYWORD="args"

		#-----------------------------------------------------------------
		# Resolve the location of the 'uname' command
		#-----------------------------------------------------------------
		UNAMEEXE="/usr/bin/uname"
		if [ ! -x "$UNAMEEXE" ]
		then
			UNAMEEXE="/bin/uname"
			if [ ! -x "$UNAMEEXE" ]
			then
				echo "Unable to locate 'uname'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'id' command
		#-----------------------------------------------------------------
		IDEXE="/usr/bin/id"
		if [ ! -x "$IDEXE" ]
		then
			IDEXE="/bin/id"
			if [ ! -x "$IDEXE" ]
			then
				echo "Unable to locate 'id'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'cut' command
		#-----------------------------------------------------------------
		CUTEXE="/usr/bin/cut"
		if [ ! -x "$CUTEXE" ]
		then
			CUTEXE="/bin/cut"
			if [ ! -x "$CUTEXE" ]
			then
				echo "Unable to locate 'cut'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		WHOAMI=`$IDEXE | $CUTEXE -d "(" -f2 | $CUTEXE -d ")" -f1`

		#-----------------------------------------------------------------
		# Resolve the location of the 'cat' command
		#-----------------------------------------------------------------
		CATEXE="/usr/bin/cat"
		if [ ! -x "$CATEXE" ]
		then
			CATEXE="/bin/cat"
			if [ ! -x "$CATEXE" ]
			then
				echo "Unable to locate 'cat'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'mv' command
		#-----------------------------------------------------------------
		MVEXE="/usr/bin/mv"
		if [ ! -x "$MVEXE" ]
		then
			MVEXE="/bin/mv"
			if [ ! -x "$MVEXE" ]
			then
				echo "Unable to locate 'mv'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'ping' command
		#-----------------------------------------------------------------
		PINGEXE="/usr/bin/ping"
		if [ ! -x "$PINGEXE" ]
		then
			PINGEXE="/etc/ping"
			if [ ! -x "$PINGEXE" ]
			then
				echo "Unable to locate 'ping'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'sed' command
		#-----------------------------------------------------------------
		SEDEXE="/usr/bin/sed"
		if [ ! -x "$SEDEXE" ]
		then
			SEDEXE="/bin/sed"
			if [ ! -x "$SEDEXE" ]
			then
				echo "Unable to locate 'sed'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'grep' command
		#-----------------------------------------------------------------
		GREPEXE="/usr/bin/grep"
		if [ ! -x "$GREPEXE" ]
		then
			GREPEXE="/bin/grep"
			if [ ! -x "$GREPEXE" ]
			then
				echo "Unable to locate 'grep'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'rm' command
		#-----------------------------------------------------------------
		RMEXE="/usr/bin/rm"
		if [ ! -x "$RMEXE" ]
		then
			RMEXE="/bin/rm"
			if [ ! -x "$RMEXE" ]
			then
				echo "Unable to locate 'rm'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'sleep' command
		#-----------------------------------------------------------------
		SLEEPEXE="/usr/bin/sleep"
		if [ ! -x "$SLEEPEXE" ]
		then
			SLEEPEXE="/bin/sleep"
			if [ ! -x "$SLEEPEXE" ]
			then
				echo "Unable to locate 'sleep'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'awk' command
		#-----------------------------------------------------------------
		AWKEXE="/usr/bin/awk"
		if [ ! -x "$AWKEXE" ]
		then
			AWKEXE="/bin/awk"
			if [ ! -x "$AWKEXE" ]
			then
				echo "Unable to locate 'awk'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'mkdir' command
		#-----------------------------------------------------------------
		MKDIREXE="/usr/bin/mkdir"
		if [ ! -x "$MKDIREXE" ]
		then
			MKDIREXE="/bin/mkdir"
			if [ ! -x "$MKDIREXE" ]
			then
				echo "Unable to locate 'mkdir'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'cp' command
		#-----------------------------------------------------------------
		CPEXE="/usr/bin/cp"
		if [ ! -x "$CPEXE" ]
		then
			CPEXE="/bin/cp"
			if [ ! -x "$CPEXE" ]
			then
				echo "Unable to locate 'cp'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'chmod' command
		#-----------------------------------------------------------------
		CHMODEXE="/usr/bin/chmod"
		if [ ! -x "$CHMODEXE" ]
		then
			CHMODEXE="/bin/chmod"
			if [ ! -x "$CHMODEXE" ]
			then
				echo "Unable to locate 'chmod'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'chown' command
		#-----------------------------------------------------------------
		CHOWNEXE="/usr/bin/chown"
		if [ ! -x "$CHOWNEXE" ]
		then
			CHOWNEXE="/bin/chown"
			if [ ! -x "$CHOWNEXE" ]
			then
				echo "Unable to locate 'chown'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'ln' command
		#-----------------------------------------------------------------
		LNEXE="/usr/bin/ln"
		if [ ! -x "$LNEXE" ]
		then
			LNEXE="/bin/ln"
			if [ ! -x "$LNEXE" ]
			then
				echo "Unable to locate 'ln'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'tr' command
		#-----------------------------------------------------------------
		TREXE="/usr/bin/tr"
		if [ ! -x "$TREXE" ]
		then
			TREXE="/bin/tr"
			if [ ! -x "$TREXE" ]
			then
				echo "Unable to locate 'tr'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		CPUCHK=`$UNAMEEXE -p`
		CINAME=`$UNAMEEXE -n`
		OSNAME=`$UNAMEEXE`
		#-----------------------------------------------------------------
		# Resolve the location of the 'oslevel' command
		#-----------------------------------------------------------------
		OSLEVELEXE="/usr/bin/oslevel"
		if [ ! -x "$OSLEVELEXE" ]
		then
			OSLEVELEXE="/bin/oslevel"
			if [ ! -x "$OSLEVELEXE" ]
			then
				echo "Unable to locate 'oslevel'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

	}
	############################################################################################
	# Resolve the Operating System
	############################################################################################
	resolve_OperatingSystem () {
		#-----------------------------------------------------------------
		# Resolve the OS
		#-----------------------------------------------------------------
		DIST_OS=`$UNAMEEXE -s | $TREXE [:upper:] [:lower:] | $TREXE -d [:blank:]`
		case "$DIST_OS" in
			'linux')
				if [ "$OSTYPE" = "linux" ]
				then
					# SLES, 
					DIST_OS="linux"
				else
					# RedHat, CentOS, Pear, Ubuntu, Mint, Peppermint
					DIST_OS="linux-gnu"
				fi

				OSCHK=`$CATEXE /etc/*-release`
				;;
			'sunos')
				DIST_OS="solaris"
				OSCHK="Solaris"
				;;
			'hp-ux' | 'hp-ux64')
				DIST_OS="hpux"
				OSCHK="HP-UX"
				;;
			'darwin')
				DIST_OS="macosx"
				PSKEYWORD="command"
				OSCHK="Mac OS-X"
				;;
			'unix_sv')
				DIST_OS="unixware"
				OSCHK="UNIX SV"
				;;
			'aix')
				DIST_OS="aix"
				OSCHK="AIX"
				;;
		esac
	}
	############################################################################################
	# Resolve the Architecture
	############################################################################################
	resolve_Architecture () {
		#-----------------------------------------------------------------
		# Resolve the architecture
		#-----------------------------------------------------------------
		UNAME_PROC_OPTION="-m"
		if [ "$DIST_OS" = "aix" ]; then
			UNAME_PROC_OPTION="-p"
		fi

		PROC_ARCH=`$UNAMEEXE $UNAME_PROC_OPTION | $TREXE [:upper:] [:lower:] | $TREXE -d [:blank:]`

		while :
		do
			case "$PROC_ARCH" in
				'amd64' | 'athlon' | 'i386' | 'i486' | 'i586' | 'i686' | 'x86_64' | 'i86pc')
					DIST_ARCH="x86"
					break;;
				'ia32' | 'ia64')
					 DIST_ARCH="ia"
					break;;
				'ip27')
					DIST_ARCH="mips"
					break;;
				'power' | 'powerpc' | 'power_pc' | 'ppc64' | 'powermacintosh')
					DIST_ARCH="ppc"
					break;;
				'pa_risc' | 'pa-risc')
					DIST_ARCH="parisc"
					break;;
				'sun4u' | 'sun4v' | 'sparcv9' | 'sparc')
					DIST_ARCH="sparc"
					break;;
				'9000/800' | '9000/785')
					DIST_ARCH="parisc"
					break;;
				*)
					echo "Your machine's hardware type ($UNAMEEXE $UNAME_PROC_OPTION) = $PROC_ARCH was not recognized by the Service Wrapper as a supported platform."
					echo "Please report this message along with your machine's processor/architecture."
					exit 1
					;;
			esac
		done
	}
resolve_Executables
resolve_OperatingSystem
resolve_Architecture
####################################################################################################
# Variables
####################################################################################################
INSTALLERLOG="/var/tmp/flex_agent_install.log"
FSMUSER="root"
FSMGROUP="system"
FSUSER="firescop"
FSGROUP="firescop"
CURDIR=`pwd`
CINAME=`$UNAMEEXE -n`
BASEDIR="/opt/firescope"
REQUIRED_VERSION=1.6
APORT="8042"
SPORT="8043"
MPORT="8044"
DACTIVE="0"
UPGRADE="0"
JMX="false"
RMTCMD="1"
REALTIME="1"
STORETIME="300"
STORECOUNT="100"
INSTALLER="FireScope_flex_agent_Installer.sh"
CPUCHK=`oslevel -r`
OSTYPE=`echo $OSTYPE`
CPUCHK=`$OSLEVELEXE -r`
DATE=`date`
WHOAMI=`$IDEXE | $CUTEXE -d "(" -f2 | $CUTEXE -d ")" -f1`
SKIPJAVACHECK=""
####################################################################################################
# End - Variables
####################################################################################################
####################################################################################################
# functions
####################################################################################################

	############################################################################################
	# FireScope Agent Help Function
	############################################################################################
	show_help () {
		HELPUSAGE="$INSTALLER -A XXX.XXX.XXX.XXX [ options ]"
		HELPAPPLIANCE="-A : Appliance IP or DNS name. Usage FireScope_Agent_Installer.sh -a XXX.XXX.XXX.XXX(Required - IP or DNS Name to FireScope Appliance.)"
		HELPBASEINTALLPATH="-b : InstallPath - Path to install the FireScope Agent. default - /opt/firescope"
		HELPREMOTECOMMAND="-c : RemoteCommand - Allows the FireScope Appliance to send commands to the agent to execute. default 0 (Valid 1 on - 0 off)"
		HELPDISABLEACTIVE="-d : DisableActive - Disables Active checks. default 0 (Valid 1 on - 0 off)"
		HELPHELP="-h : Help - Displays this help file"
		HELPHOSTNAME="-H : CINAME - Hostname or name used to ID the system in the FireScope Appliance. Must match for AgentRemote to work properly."
		HELPJAVAPATH="-j : Path to the Java installation to be used (/usr/java/jre1.6.0_21/bin/java)"
		HELPMANAGERPORT="-m : ManagerPort - Port used by the agent manager to receive data from the FireScope Appliance. default - 8044 (Valid 1-65535)"
		HELPSTORECOUNT="-n : Storecount - Used in Store&Foward mode. The number of metrics stored before sending. default - 100 (valid 10-200)"
		HELPAGENTPORT="-p : AgentPort - Port used by the agent to receive data from the FireScope Appliance. default - 8042 (Valid 1-65535)"
		HELPREALTIME="-s : Realtime - Sets the FireScope Agent to realtime mode. default - 1 (Valid 1-Realtime 0-Store&Forward)"
		HELPSTORETIME="-t : Storetime - Used in Store&Foward mode. The amount of time in seconds that the agent will cache metrics before sending. default - 300 (Valid 30 - 600)"
		HELPUPGRADE="-u : Upgrade - Used to upgrade a legacy flex_agent.conf to a flex_agent_posix.xml"
		HELPEXAMPLE="e.g. $INSTALLER -A 10.0.2.40 -b /opt/firescope -p 8042 -c 1 -H myserver -s 1 -t 200 -n 400"
		SHOW_HELP="$HELPUSAGE\n\t$HELPAPPLIANCE\n\t$HELPBASEINTALLPATH\n\t$HELPREMOTECOMMAND\n\t$HELPDISABLEACTIVE\n\t$HELPHELP\n\t$HELPHOSTNAME\n\t$HELPMANAGERPORT\n\t$HELPSTORECOUNT\n\t$HELPOSTYPE\n\t$HELPAGENTPORT\n\t$HELPREALTIME\n\t$HELPSTORETIME\n\t$HELPUPGRADE\n\t$HELPEXAMPLE"
		echo "$SHOW_HELP"
		exit 1
	}
	############################################################################################
	# Install directory structure function
	############################################################################################
	install_directories () {
		AGENTDIR="$BASEDIR/agent"
		MANAGERDIR="$BASEDIR/agent_manager"

		FLEXAGENT_BINS="$CURDIR/firescope"
		AIX_INIT_SOURCE="$CURDIR/etc/init.d/AIX"
		INIT_DEST="/etc/rc.d/init.d"
		INIT_DEST2="/etc/rc.d/rc2.d"
		INIT_DEST5="/etc/rc.d/rc5.d"

		AGENT_PID_FILES="$CURDIR/firescope/agent/logs"
		AGENT_PID_DEST_FILES="$AGENTDIR/logs"
		JMXDIR="$AGENTDIR/modules/jmxdelegate"
		CONFIGFILE="${AGENTDIR}/conf/flex_agent_posix.xml"
		CONFIGFILEBASE="${AGENTDIR}/conf"
		RELEASENOTESSOURCE="${CURDIR}/ReleaseNotes.txt"
		RELEASENOTESDEST="${AGENTDIR}/docs/ReleaseNotes.txt"
		SCRIPTSSOURCE="${CURDIR}/firescope/agent/scripts"
		SCRIPTSDEST="${AGENTDIR}/scripts"
		JAVAPARMS=" -Djava.library.path=$AGENTDIR/bin/lib -jar "

		echo "creating dir structure" >>$INSTALLERLOG
		mkdir -p $BASEDIR >>$INSTALLERLOG
		mkdir -p $AGENTDIR >>$INSTALLERLOG
		mkdir -p $AGENTDIR/bin >>$INSTALLERLOG
		mkdir -p $AGENTDIR/.agent >>$INSTALLERLOG
		mkdir -p $AGENTDIR/cache >>$INSTALLERLOG
		mkdir -p $AGENTDIR/conf >>$INSTALLERLOG
		mkdir -p $AGENTDIR/docs >>$INSTALLERLOG
		mkdir -p $AGENTDIR/logs >>$INSTALLERLOG
		mkdir -p $AGENTDIR/scripts >>$INSTALLERLOG
		mkdir -p $AGENTDIR/backup >>$INSTALLERLOG
		if [ "$SKIPAGENTMANAGER" != "1" ]; then	
			mkdir -p $MANAGERDIR >>$INSTALLERLOG
			mkdir -p $MANAGERDIR/.agent_manager >>$INSTALLERLOG
			mkdir -p $MANAGERDIR/temp >>$INSTALLERLOG
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped mkdir of manager" >>$INSTALLERLOG
		fi
	################################
	# Echo to $INSTALLERLOG
	################################

		echo "$DATE == $WHOAMI mkdir Variables" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI BASEDIR=$BASEDIR" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI AGENTDIR=$AGENTDIR" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI AGENTDIR/bin-$AGENTDIR/bin" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI AGENTDIR/.agent=$AGENTDIR/.agent" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI AGENTDIR/cache=$AGENTDIR/cache" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI AGENTDIR/conf=$AGENTDIR/conf" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI AGENTDIR/logs=$AGENTDIR/logs" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI AGENTDIR/scripts=$AGENTDIR/scripts" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI AGENTDIR/backup=$AGENTDIR/backup" >>$INSTALLERLOG
		if [ "$SKIPAGENTMANAGER" != "1" ]; then	
			echo "$DATE == $WHOAMI MANAGERDIR=$MANAGERDIR" >>$INSTALLERLOG
			echo "$DATE == $WHOAMI MANAGERDIR/.agent_manager=$MANAGERDIR/.agent_manager" >>$INSTALLERLOG
			echo "$DATE == $WHOAMI MANAGERDIR/temp=$MANAGERDIR/temp" >>$INSTALLERLOG
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped echo of manager" >>$INSTALLERLOG
		fi
	################################
	# Echo to $MANAGERDIR/.agent_manager/agent_paths
	################################

		echo "$DATE == $WHOAMI mkdir Variables" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI BASEDIR=$BASEDIR" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI AGENTDIR=$AGENTDIR" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI AGENTDIR/bin-$AGENTDIR/bin" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI AGENTDIR/.agent=$AGENTDIR/.agent" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI AGENTDIR/cache=$AGENTDIR/cache" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI AGENTDIR/conf=$AGENTDIR/conf" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI AGENTDIR/logs=$AGENTDIR/logs" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI AGENTDIR/scripts=$AGENTDIR/scripts" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI AGENTDIR/backup=$AGENTDIR/backup" >>$MANAGERDIR/.agent_manager/agent_paths
		if [ "$SKIPAGENTMANAGER" != "1" ]; then	
			echo "$DATE == $WHOAMI MANAGERDIR=$MANAGERDIR" >>$MANAGERDIR/.agent_manager/agent_paths
			echo "$DATE == $WHOAMI MANAGERDIR/.agent_manager=$MANAGERDIR/.agent_manager" >>$MANAGERDIR/.agent_manager/agent_paths
			echo "$DATE == $WHOAMI MANAGERDIR/temp=$MANAGERDIR/temp" >>$MANAGERDIR/.agent_manager/agent_paths
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped agent paths of manager" >>$INSTALLERLOG
		fi
	}
	############################################################################################
	# End - install_directories 
	############################################################################################

	############################################################################################
	# Start - sedreplace function
	############################################################################################
	# Usage
	# sedreplace $1 $2 $3
	# $1 what to search for
	# $2 file to search in
	# $3 line offset in numbers
	# $4 what to replace with
	# e.g. sedreplace "AGENTDIR=AGENTDIR" "$INIT_DEST"/flex_agent 0 "AGENTDIR=$AGENTDIR"
	############################################################################################
	sedreplace () {
		AIModeKey=`$GREPEXE -n "$1" "$2" | $CUTEXE -d ":" -f1`
		echo "AIModeKey=$AIModeKey"  >>$INSTALLERLOG
		AIModeValue=`expr $AIModeKey + $3` >>$INSTALLERLOG
		echo "AIModeValue=$AIModeValue"  >>$INSTALLERLOG
		sedLine=`$SEDEXE $AIModeValue'q;d' $2` >>$INSTALLERLOG
		echo "sedLine=$sedLine"  >>$INSTALLERLOG
		sedLine1=`echo $sedLine | $CUTEXE -d '>' -f2 | $CUTEXE -d '<' -f1`
		echo "sedLine1=$sedLine1"  >>$INSTALLERLOG
		sedLine2="$4" >>$INSTALLERLOG
		echo "sedLine2=$sedLine2"  >>$INSTALLERLOG
		$CPEXE -f "$2" "$2-old"
		$SEDEXE -e "$AIModeValue"'s;'"$sedLine1"';'"$sedLine2"';g' $2 >> "$2-new"
		$MVEXE -f "$2-new" "$2"
		$RMEXE -f "$2-new"
	}
	############################################################################################
	# End - sedreplace function
	############################################################################################
	############################################################################################
	# Agent init sed replace function
	############################################################################################
	agent_init_sed () {
		echo "****************************Agent init set agent path 'Agent init sed replace function' $AGENTDIR***************************" >>$INSTALLERLOG
			sedreplace "AGENTDIR=AGENTDIR" "$INIT_DEST"/flex_agent 0 "AGENTDIR=$AGENTDIR"
		echo "****************************Agent init set config path 'Agent init sed replace function' $CONFIGFILE***************************" >>$INSTALLERLOG
			sedreplace "agentd_cfgfile=agentd_cfgfile" "$INIT_DEST/flex_agent" 0 "agentd_cfgfile=$CONFIGFILE"
		echo "****************************Agent init set pid path 'Agent init sed replace function' $AGENTDIR/logs/flex_agent.pid***************************" >>$INSTALLERLOG
			sedreplace "PIDFILE=PIDFILE" "$INIT_DEST/flex_agent" 0 "PIDFILE=$AGENTDIR/logs/flex_agent.pid"
		echo "****************************Agent init command 'Agent init sed replace function' $FSUSER***************************" >>$INSTALLERLOG
			sedreplace "FSUSER=FSUSER" "$INIT_DEST/flex_agent" 0 "FSUSER=$FSUSER"
		echo "****************************Agent init command 'Agent init sed replace function' $AGENTDIR/bin/flex_agent.jar***************************" >>$INSTALLERLOG
			sedreplace "FLEXAGENT=FLEXAGENT" "$INIT_DEST/flex_agent" 0 "FLEXAGENT=$AGENTDIR/bin/flex_agent.jar"
		echo "****************************Agent init command 'Agent init sed replace function' $JAVAPATH***************************" >>$INSTALLERLOG
			sedreplace "JAVAPATH=JAVAPATH" "$INIT_DEST/flex_agent" 0 "JAVAPATH=\"$JAVAPATH\""
		echo "****************************Agent init command 'Agent init sed replace function' $JAVAPARMS***************************" >>$INSTALLERLOG
			sedreplace "JAVAPARMS=JAVAPARMS" "$INIT_DEST/flex_agent" 0 "JAVAPARMS=\"$JAVAPARMS\""
	}
	############################################################################################
	# End - Agent init sed replace function
	############################################################################################

	############################################################################################
	# Agent Manager init sed replace function
	############################################################################################
	agent_manager_init_sed () {
		echo "****************************Agent manager init set agent path 'Agent Manager init sed replace function' $MANAGERDIR***************************" >>$INSTALLERLOG
			sedreplace "MANAGERDIR=MANAGERDIR" "$INIT_DEST/flex_agent_manager" 0 "MANAGERDIR=$MANAGERDIR"
		echo "****************************Agent manager init set config path 'Agent init sed replace function' $CONFIGFILE***************************" >>$INSTALLERLOG
			sedreplace "agentd_cfgfile=agentd_cfgfile" "$INIT_DEST/flex_agent_manager" 0 "agentd_cfgfile=$CONFIGFILE"
		echo "****************************Agent manager init set pid path 'Agent init sed replace function' $AGENTDIR/logs/flex_agent_manager.pid***************************" >>$INSTALLERLOG
			sedreplace "PIDFILE=PIDFILE" "$INIT_DEST/flex_agent_manager" 0 "PIDFILE=$AGENTDIR/logs/flex_agent_manager.pid"
		echo "****************************Agent manager init set FSMUSER  'Agent init sed replace function' $FSMUSER***************************" >>$INSTALLERLOG
			sedreplace "FSMUSER=FSMUSER" "$INIT_DEST/flex_agent_manager" 0 "FSMUSER=$FSMUSER"
		echo "****************************Agent manager init set manager path 'Agent init sed replace function' $MANAGERDIR/flex_agent_manager.jar***********************" >>$INSTALLERLOG
			sedreplace "FLEXAGENTMANAGER=FLEXAGENTMANAGER" "$INIT_DEST/flex_agent_manager" 0 "FLEXAGENTMANAGER=$MANAGERDIR/flex_agent_manager.jar"
		echo "****************************Agent init command 'Agent init sed replace function' $JAVAPATH***************************" >>$INSTALLERLOG
			sedreplace "JAVAPATH=JAVAPATH" "$INIT_DEST/flex_agent_manager" 0 "JAVAPATH=\"$JAVAPATH\""
		echo "****************************Agent init command 'Agent init sed replace function' $JAVAPARMS***************************" >>$INSTALLERLOG
			sedreplace "JAVAPARMS=JAVAPARMS" "$INIT_DEST/flex_agent_manager" 0 "JAVAPARMS=\"$JAVAPARMS\""
	}
	############################################################################################
	# End - Agent Manager init sed replace function
	############################################################################################
	############################################################################################
	# Uninstaller sed replace function
	############################################################################################
	uninstaller_sed () {
	echo "****************************Agent uninstall dir. 'Uninstaller sed replace function '***************************" >>$INSTALLERLOG
		sedreplace "INIT=INIT" "$AGENTDIR"/FireScope_Agent_Uninstall.sh 0 "INIT=$INIT_DEST"
		sedreplace "INSTALLDIR=INSTALLDIR" "$AGENTDIR"/FireScope_Agent_Uninstall.sh 0 "INSTALLDIR=$BASEDIR"
			`$RMEXE "$AGENTDIR"/FireScope_Agent_Uninstall.sh-old`
	}
	############################################################################################
	# End - Uninstaller sed replace function
	############################################################################################
####################################################################################################
# copycorefiles function start
####################################################################################################
# Usage
# copycorefiles $1 $2
# $1 OS Bins (i.e. $FLEXAGENT_BINS, $REDHAT_5_64_BINS, ...)
# $2 INIT Files (i.e. $AIX_INIT_SOURCE, $REDHAT_64_INIT, ...)
# e.g. copycorefiles
####################################################################################################
copycorefiles () {
		#------------------------------------------------------------------------------------
		# Copy agent files
		#------------------------------------------------------------------------------------
		echo "Copying $1 Agent bin" >>$INSTALLERLOG
		$CPEXE -rf $1/agent/bins/flex_agent/* $AGENTDIR/bin/ >>$INSTALLERLOG
		$CPEXE $RELEASENOTESSOURCE $RELEASENOTESDEST >>$INSTALLERLOG
		$CPEXE $AGENT_PID_FILES/flex_agent.pid $AGENT_PID_DEST_FILES/ >>$INSTALLERLOG
		#------------------------------------------------------------------------------------
		# Create a symbolic link for AIX 7
		#------------------------------------------------------------------------------------
		ln -sf $AGENTDIR/bin/lib/libsigar-ppc-aix-5.so $AGENTDIR/bin/lib/libsigar-ppc-aix-7.so
		ln -sf $AGENTDIR/bin/lib/libsigar-ppc64-aix-5.so $AGENTDIR/bin/lib/libsigar-ppc64-aix-7.so

		#------------------------------------------------------------------------------------
		# Copy agent manager files
		#------------------------------------------------------------------------------------
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			echo "Copying $1 Agent Manager bins" >>$INSTALLERLOG
			$CPEXE $AGENT_PID_FILES/flex_agent_manager.pid $AGENT_PID_DEST_FILES/ >>$INSTALLERLOG
			$CPEXE $1/agent_manager/flex_agent_manager.jar $MANAGERDIR
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped upgrading manager" >>$INSTALLERLOG
		fi
		#------------------------------------------------------------------------------------
		# Copy agent init files
		#------------------------------------------------------------------------------------
		$CPEXE $2/flex_agent $INIT_DEST >>$INSTALLERLOG
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			$CPEXE $2/flex_agent_manager $INIT_DEST >>$INSTALLERLOG
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skippedcopy init manager" >>$INSTALLERLOG
		fi
		#------------------------------------------------------------------------------------
		# Chmod agent init files
		#------------------------------------------------------------------------------------
		$CHMODEXE +x $INIT_DEST/flex_agent >>$INSTALLERLOG
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			$CHMODEXE +x $INIT_DEST/flex_agent_manager >>$INSTALLERLOG
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped chmod manager" >>$INSTALLERLOG
		fi

		echo "Copying AIX Agent Uninstaller script" >>$INSTALLERLOG
		$CPEXE $1/agent/FireScope_Agent_Uninstall.sh $AGENTDIR/FireScope_Agent_Uninstall.sh >>$INSTALLERLOG
	}
	#############################################################################################
	# End - copycorefiles function
	#############################################################################################
	#############################################################################################
	# Setup init function
	#############################################################################################
	setup_init () {
			SERVICE_START="$INIT_DEST/flex_agent start"
			SERVICE_STOP="$INIT_DEST/flex_agent stop"
		####################################################################################
		# Start - agent_init_sed
		####################################################################################
			uninstaller_sed

		####################################################################################
		# Start - agent_init_sed
		####################################################################################
			agent_init_sed
			$CHMODEXE +x "$INIT_DEST"/flex_agent

		####################################################################################
		# Start - agent_manager_init_sed
		####################################################################################
			if [ "$SKIPAGENTMANAGER" != "1" ]; then
				agent_manager_init_sed >>$INSTALLERLOG
				$CHMODEXE +x "$INIT_DEST"/flex_agent_manager
			else
				echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped init of agent_manager_init_sed" >>$INSTALLERLOG
			fi
	}
	#############################################################################################
	# init_on_boot function
	#############################################################################################
init_on_boot () {
#####################################################################################################
# Setup INIT with OS check
#####################################################################################################
#####################################################################################################
# Available Runlevels (AIX)
#####################################################################################################
# ID                    Name                      Description
#####################################################################################################
# 0                                                              reserved
# 1                                                              reserved
#*2      Normal Multi-User mode   default mode
# 3                                                              defined by the admin
# 4                                                              defined by the admin
# 5                                                              defined by the admin
# 6                                                              defined by the admin
# 6                                                              defined by the admin
# 7                                                              defined by the admin
# 8                                                              defined by the admin
# 9                                                              defined by the admin
#####################################################################################################
        echo "cpuchk" >>$INSTALLERLOG
        echo "$CPUCHK" >>$INSTALLERLOG
#       if [ $CPUCHK = "powerpc" ]; then
                #####################################################################################
                # Link agent init files with runlevels AIX with manager upgrade check
                #####################################################################################
                if [ `lsitab -a | grep -c flex_agent` -eq "0" ]; then
                        mkitab "flex_agent:2:boot:$INIT_DEST/flex_agent start > /dev/console 2>&1" >>$INSTALLERLOG
                fi
                #####################################################################################
                # End - Link agent init files with runlevels AIX with manager upgrade check
                #####################################################################################

                #####################################################################################
                # Link agent manager init files with runlevels AIX with manager upgrade check
                #####################################################################################
                if [ "$SKIPAGENTMANAGER" != "1" ]; then
                         if [ `lsitab -a | grep -c flex_agent_mgr` -eq "0" ]; then
                                  mkitab "flex_agent_mgr:2:boot:$INIT_DEST/flex_agent_manager start > /dev/console 2>&1" >>$INSTALLERLOG
                         fi
                else
                        echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped link init manager" >>$INSTALLERLOG
                fi
                ####################################################################################################
                # End - Link agent manager init files with runlevels AIX with manager upgrade check
                ####################################################################################################

                ####################################################################################################
                # Chmod agent init files AIX with manager upgrade check
                ####################################################################################################
                $CHMODEXE +x $INIT_DEST/flex_agent >>$INSTALLERLOG
                if [ "$SKIPAGENTMANAGER" != "1" ]; then
                        $CHMODEXE +x $INIT_DEST/flex_agent_manager >>$INSTALLERLOG
                else
                        echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped chmod manager" >>$INSTALLERLOG
                fi
                ####################################################################################################
                # End - Chmod agent init files AIX with manager upgrade check
                ####################################################################################################

#       fi
########################################################################################################
# End - Setup INIT with OS check
#######################################################################################################
}
	############################################################################################
	# End - init_on_boot function
	############################################################################################
	############################################################################################
	# checkos function start
	############################################################################################
	# Usage
	# checkos
	# e.g. checkos
	############################################################################################
	checkos () {
		echo "CPU Check = $CPUCHK" >>$INSTALLERLOG
		echo "Operating System Check = $OSCHK" >>$INSTALLERLOG
		sleep 1

		COPYFROM=$FLEXAGENT_BINS
		COPYTO=$AIX_INIT_SOURCE
	}
	############################################################################################
	# End - checkos function
	############################################################################################
	############################################################################################
	# Uninstaller sed replace function
	# PEBTODO: REMOVE INIT2 and INIT5 also
	############################################################################################
	uninstaller_sed () {
	echo "****************************Agent uninstall dir. 'Uninstaller sed replace function '***************************" >>$INSTALLERLOG
		sedreplace "INIT=INIT" "$AGENTDIR/FireScope_Agent_Uninstall.sh" 0 "INIT=$INIT_DEST"
		sedreplace "INSTALLDIR=INSTALLDIR" "$AGENTDIR/FireScope_Agent_Uninstall.sh" 0 "INSTALLDIR=$BASEDIR"
	}
	############################################################################################
	# End - Uninstaller sed replace function
	############################################################################################
################################################################################################
# End - functions
################################################################################################

if [ -f "$INSTALLERLOG" ]; then
	`$RMEXE -f $INSTALLERLOG`
fi
###########################
# FireScope Agent Getopts settings
###########################
f="0"
while getopts ":A:a:b:c:d:H:j:K:k:m:n:p:s:t:V:huZ" o
do case $o in
	###########################
	# FireScope Server Set Info
	###########################
	A)
		f="1"
		echo "Checking for connectivity to the FireScope Appliance."
		echo "$DATE == $WHOAMI Passed1FireScopeServerIP=$OPTARG"  >>$INSTALLERLOG

		if [ "$OPTARG" != "" ]; then
			SERVERCHECK=`$PINGEXE -c 3 $OPTARG | $GREPEXE -c "3 received"`
			echo "$DATE == $WHOAMI Server $PINGEXE Check = ${SERVERCHECK}"  >>$INSTALLERLOG
			echo "Checking for route to Appliance. Please standby."
			if [ ${SERVERCHECK} != "1" ]; then
				echo "Could not $PINGEXE the FireScope Server!!! Please check IP or DNS and try again."  >>$INSTALLERLOG
			fi
		else
			echo "Invalid IP address, please provide the FireScope appliance IP address."
			echo "$Installer -h more help."
			exit 1
		fi
		SERVER="$OPTARG"
		echo "$DATE == $WHOAMI Set1FireScopeServerIP=${SERVER}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Server Port
	###########################
	a)
		echo "$DATE == $WHOAMI PassedServerPort=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
			SPORT="$OPTARG"
		else
			echo "Server Port (-a) must be between 1 and 65535!!!"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetServerPort=${SPORT}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Path
	###########################
	b)
		echo "$DATE == $WHOAMI Passed2InstallPath=$OPTARG"  >>$INSTALLERLOG
		if [ "$OPTARG" = "" ]; then
			BASEDIR="/opt/firescope"
		elif [ "$OPTARG" != "" ]; then
			BASEDIR="$OPTARG"
			install_directories
		fi
		echo "$DATE == $WHOAMI Set2InstallPath=${BASEDIR}"  >>$INSTALLERLOG
	;;
	###########################
	# Java Path check
	###########################
	j)
		echo "$DATE == $WHOAMI PassedJVM=$OPTARG"  >>$INSTALLERLOG
		if [ "$OPTARG" = "" ]; then
			JAVAPATH="java"
		fi
		if [ "$OPTARG" != "" ]; then
			JAVAPATH="$OPTARG"
			SKIPJAVACHECK="1"
		fi
		echo "$DATE == $WHOAMI SetJAVAPATH=${STORETIME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Port
	###########################
	p)
		echo "$DATE == $WHOAMI Passed3Port=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
			APORT="$OPTARG"
		else
			echo "Agent Port (-p) must be between 1 and 65535!!!"
			exit 1
		fi
		echo "$DATE == $WHOAMI Set3Port=${APORT}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Manager Port
	###########################
	m)
		echo "$DATE == $WHOAMI PassedManPort=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
			MPORT="$OPTARG"
		else
			echo "Agent Manager Port (-m) must be between 1 and 65535!!!"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetManPort=${MPORT}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Remote Commands
	###########################
	c)
		echo "$DATE == $WHOAMI PassedRMTCMD=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" = "1" ]] || [[ "$OPTARG" = "0" ]]; then
			RMTCMD="$OPTARG"
		else
			RMTCMD="0"
			echo "Invalid Argument for Remote commands (-c)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetRMTCMD=${RMTCMD}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Disable Active checks
	###########################
	d)
		echo "$DATE == $WHOAMI PassedDActive=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" = "1" ]] || [[ "$OPTARG" = "0" ]]; then
			DACTIVE="$OPTARG"
		else
			RMTCMD="0"
			echo "Invalid argument for Disable Active Checks (-d)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetDActive=${DACTIVE}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Hostname
	###########################
	H)
		echo "$DATE == $WHOAMI PassedCINAME=$OPTARG"  >>$INSTALLERLOG
		if [ "$OPTARG" = "" ]; then
			CINAME=`hostname -s`
		fi
		if [ "$OPTARG" != "" ]; then
			CINAME="$OPTARG"
		fi
		echo "$DATE == $WHOAMI SetCINAME=${CINAME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Realtime
	###########################
	s)
		echo "$DATE == $WHOAMI PassedREALTIME=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" = "1" ]] || [[ "$OPTARG" = "0" ]]; then
			REALTIME="$OPTARG"
		else
			echo "Invaild argument for Agent Realtime mode (-s)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetREALTIME=${REALTIME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Storetime
	###########################
	t)
		echo "$DATE == $WHOAMI PassedSTORETIME=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "29" ] && [ "$OPTARG" -lt "601" ]; then
			STORETIME="$OPTARG"
		else
			echo "Invaild value for Store and Forward time (-t)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetSTORETIME=${STORETIME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent upgrade
	###########################
	u)
		UPGRADE="1"
	;;
	###########################
	# FireScope Agent Storecount
	###########################
	n)
		echo "$DATE == $WHOAMI PassedSTORECOUNT=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "9" ] && [ "$OPTARG" -lt "201" ]; then
			STORECOUNT="$OPTARG"
		else
			echo "Invalid value for Store and Forward Count (-n)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetSTORECOUNT=${STORECOUNT}"  >>$INSTALLERLOG
	;;
	h)
		show_help; exit 0
	;;
	Z)
		SKIPAGENTMANAGER="1"
	;;
	\?)
		echo "Invalid option: -$OPTARG"
		echo "$Installer -h for more help."
		exit 1
	;;
	:)
		echo "Option -$OPTARG requires an argument."
		echo "$Installer -h for more help."
		exit 1
	;;
	esac
done

###########################
# FireScope Check for required flags
###########################
	if [ $UPGRADE -ne "1" ]; then
		if [ "$f" = "0" ]; then
			echo "The flag -A is required
			$INSTALLER -h for more help"
			exit 1
		elif [ "$1" = "-h" ]; then
			show_help
		elif [ "$1" = "--help" ]; then
			show_help
			exit 0
		fi
	fi
####################################################################################################
#Check if user is root
####################################################################################################
	if [ "${WHOAMI}" != "root" ]; then
		echo "Sorry, root required to install agent."
		exit 1
	fi
####################################################################################################
#End Check if user is root
####################################################################################################
echo "\033[40m\033[40;33m" #sets back gound to black
####################################################################################################
#checks if there is a service account on system
####################################################################################################
	#################################
	#Begin Check
	#################################
	#Required Variables
	#################################
	# FSUSER
	# FSGROUP
	#################################
	echo "Service account check for Agent" >>$INSTALLERLOG
	IDTEST=`dispuid | $GREPEXE $FSUSER`
	echo "IDTEST=$IDTEST" >>$INSTALLERLOG
	GRPTEST=`dispgid | $GREPEXE $FSGROUP`
	echo "GRPTEST=$GRPTEST"  >>$INSTALLERLOG
	#IDUSERTEST=`$IDEXE $FSUSER | $AWKEXE '($1 ~ /\('$FSGROUP'\)/) && ($1 ~ /uid=/)' 2>/dev/null`
	COUNTER=0
	if [ -z "$GRPTEST" ]
		then
		echo "Creating Group: $FSGROUP"
			mkgroup $FSGROUP
	fi
	if [ -z "$IDTEST" ]
	then
		echo "Creating Service Account: $FSUSER"
		`useradd -g $FSUSER $FSGROUP 2>/dev/null`
	else
		echo "User and Groups exist, Upgrading Agent Installation...."  2>&1 >>$INSTALLERLOG
	fi
####################################################################################################
# Future error check code
####################################################################################################
#					echo "Verifing Service Account"
#						if [ -z "$IDUSERTEST" ]
#							then
#								while [  $COUNTER -lt 3 ]; do
#										echo "Cannot Create Service Account: firescop"
#								let COUNTER=COUNTER+1
#								done
####################################################################################################
################################
#End Check
################################
############################
# Presentation
############################
	echo "\033[40m\033[40;31m\n\nFire\033[37mScope\033[33m Agent $VERSION Installer for $OSNAME\n=====================================================================================\n"
####################################################################################################
# Check Java Version
####################################################################################################
# Transform the required version string into a number that can be used in comparisons
if [ $SKIPJAVACHECK -ne "1" ]
then
	REQUIRED_VERSION=`echo $REQUIRED_VERSION | $SEDEXE -e 's;\.;0;g'`
	# Check JAVA_HOME directory to see if Java version is adequate
	#if [ -z "$JAVA_HOME" ]; then
	#	echo "Installation Stopped!! Java $JAVA_VERSION is not $REQUIRED_VERSION or higher.\n=====================================================================================\n\n"
	#	echo "\033[0m" # sets background back to default
	#	exit 0
	#else
	#	echo "\033[40m\033[40;31m\n\nFire\033[37mScope\033[33m Agent v$VERSION for $OSNAME Checking Java Version...\n=====================================================================================\n\n"
	#fi

	if [ $JAVA_HOME ]
	then
		JAVA_EXE=$JAVA_HOME/bin/java
		$JAVA_EXE -version 2> tmp.ver
		JAVA_VERSION=`$CATEXE tmp.ver | $GREPEXE "java version" | $AWKEXE '{ print substr($3, 2, length($3)-2); }'`
		$RMEXE tmp.ver
		JAVA_VERSION=`echo $JAVA_VERSION | $AWKEXE '{ print substr($1, 1, 3); }' | $SEDEXE -e 's;\.;0;g'`
		if [ $VERSION ]
		then
			if [ $JAVA_VERSION -ge $REQUIRED_VERSION ]
			then
				JAVA_HOME=`echo $JAVA_EXE | $AWKEXE '{ print substr($1, 1, length($1)-9); }'`
			else
				JAVA_HOME=
			fi
		else
			JAVA_HOME=
		fi
	fi
	
	# If the existing JAVA_HOME directory is adequate, then leave it alone
	# otherwise, use 'find' to search for other possible java candidates and
	# check their versions.
	if [ $JAVA_HOME ]
	then
		:
	else
		for JAVA_EXE in `find /usr -name java | $GREPEXE bin/java$ | xargs echo`
		do
			if [ $JAVA_HOME ] 
			then
				:
			else
				$JAVA_EXE -version 2> tmp.ver 1> /dev/null
				JAVA_VERSION=`$CATEXE tmp.ver | $GREPEXE "java version" | $AWKEXE '{ print substr($3, 2, length($3)-2); }'`
				$RMEXE tmp.ver
				JAVA_VERSION=`echo $JAVA_VERSION | $AWKEXE '{ print substr($1, 1, 3); }' | $SEDEXE -e 's;\.;0;g'`
				if [ $JAVA_VERSION ]
				then
					if [ $JAVA_VERSION -ge $REQUIRED_VERSION ]
					then
						JAVA_HOME=`echo $JAVA_EXE | $AWKEXE '{ print substr($1, 1, length($1)-9); }'`
					fi
				fi
			fi
		done
	fi

	# If the correct Java version is detected, then export the JAVA_HOME environment variable
	if [ $JAVA_HOME ]
	then
		export JAVA_HOME
		JAVAPATH="$JAVA_HOME/bin/java"
		echo "JAVAPATH=$JAVAPATH" >>$INSTALLERLOG
		echo $JAVA_HOME >>$INSTALLERLOG
		#echo $JAVA_HOME >> $INSTALLERLOG
	else
		echo "Installation Stopped!!! Java $JAVA_VERSION is not $REQUIRED_VERSION or higher."
		echo "Please set the JAVA_HOME directory or supply the path to java using the -j <path> switch."
		echo "==========================================================================================="
		echo "\033[0m" # sets background back to default
		exit 0
	fi
fi
####################################################################################################
# Copy core files
####################################################################################################
	install_directories
	checkos
	copycorefiles $COPYFROM $COPYTO
	echo "Copying AIX Agent Uninstaller script" >>$INSTALLERLOG
####################################################################################################
# End - Copy core files
####################################################################################################

####################################################################################################
# chmod agent and agent manager bins
####################################################################################################
		$CHMODEXE +x $AGENTDIR/FireScope_Agent_Uninstall.sh >>$INSTALLERLOG
		$CHMODEXE +x $AGENTDIR/bin/flex_agent.jar >>$INSTALLERLOG
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			$CHMODEXE +x $MANAGERDIR/flex_agent_manager.jar >>$INSTALLERLOG
		fi
####################################################################################################
# End - chmod agent and agent manager bins
####################################################################################################
####################################################################################################
# Start - init_on_boot
####################################################################################################
init_on_boot
####################################################################################################
# End - init_on_boot
####################################################################################################
####################################################################################################
# Set some user input and collected values in config file
####################################################################################################
	setup_init

	###############################################
	# check for .conf and convert
	###############################################
		if [ -f $CONFIGFILEBASE/flex_agent.conf ]; then
			echo "### Conf upgrade conf --> xml ###" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent.conf -u "" >>$INSTALLERLOG
					echo 'Upgrading conf--->xml $AGENTDIR/bin/flex_agent -c $CONFIGFILEBASE/flex_agent.conf -u ""' >>$INSTALLERLOG
					echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
	###############################################
	# check for .xml and convert
	###############################################
	elif [ -f $CONFIGFILEBASE/flex_agent_posix.xml ]; then >>$INSTALLERLOG
		echo "### Conf upgrade xml --> xml ###"  >>$INSTALLERLOG
			$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "" >>$INSTALLERLOG
				 echo 'Upgrading xml--->xml $AGENTDIR/bin/flex_agent -c $CONFIGFILEBASE/flex_agent_posix.xml -u ""' >>$INSTALLERLOG
				 echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
	###############################################
	# create new config xml file
	###############################################
	else
		echo "### New Config XML Created ###" >>$INSTALLERLOG
		####################################################################################
		# New Config xml created
		####################################################################################
			echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
			echo "Building new xml $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent.conf -u AgentServiceName=flex_agent|AgentServiceStart=$SERVICE_START|AgentServiceStop=$SERVICE_STOP" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "AgentServiceName=flex_agent|AgentServiceStart=$SERVICE_START|AgentServiceStop=$SERVICE_STOP" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u ListenIP=0.0.0.0|ManagerIP=|Server=$SERVER|ServerPort=$SPORT|Hostname=$CINAME|EnableRemoteCommands=$RMTCMD|DisableActive=$DACTIVE" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "ListenIP=0.0.0.0|ManagerIP=|Server=$SERVER|ServerPort=$SPORT|Hostname=$CINAME|EnableRemoteCommands=$RMTCMD|DisableActive=$DACTIVE" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u ListenPort=$APORT|TempFileLocation=$AGENTDIR/cache|LogFile=$AGENTDIR/logs/flex_agent.log|PidFile=$AGENTDIR/logs/flex_agent.pid" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "ListenPort=$APORT|TempFileLocation=$AGENTDIR/cache|LogFile=$AGENTDIR/logs/flex_agent.log|PidFile=$AGENTDIR/logs/flex_agent.pid" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u AgentImmediateMode=$REALTIME|AgentStoreDurationSeconds=$STORETIME|AgentStoreCount=$STORECOUNT" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "AgentImmediateMode=$REALTIME|AgentStoreDurationSeconds=$STORETIME|AgentStoreCount=$STORECOUNT" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u ManagerPort=$MPORT|ManagerInstallationRoot=$MANAGERDIR|ManagerLogFile=$AGENTDIR/logs/flex_agent_manager.log|ManagerPidFile=$AGENTDIR/logs/flex_agent_manager.pid|ManagerIp=0.0.0.0" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "ManagerPort=$MPORT|ManagerInstallationRoot=$MANAGERDIR|ManagerLogFile=$AGENTDIR/logs/flex_agent_manager.log|ManagerPidFile=$AGENTDIR/logs/flex_agent_manager.pid|ManagerIp=0.0.0.0" >>$INSTALLERLOG
	fi
####################################################################################################
# End - Set some user input and collected values in config file
####################################################################################################
####################################################################################################
# Copy agent version file
####################################################################################################
	echo "$INSTALLER" > $AGENTDIR/.agent/flex_agent_version
	if [ "$SKIPAGENTMANAGER" != "1" ]; then
		echo "$VERSION" > $MANAGERDIR/.agent_manager/flex-agent_manager_version
	fi
####################################################################################################
# Chmod uninstall.sh script
####################################################################################################
	$CHMODEXE +x $AGENTDIR/FireScope_Agent_Uninstall.sh
####################################################################################################
# Chown the firescope directory and all child directory to be owned by firescop
####################################################################################################
	$CHOWNEXE -R $FSUSER:$FSGROUP $BASEDIR >>$INSTALLERLOG
	if [ "$SKIPAGENTMANAGER" != "1" ]; then
		$CHOWNEXE -R $FSMUSER:$FSMGROUP $MANAGERDIR >>$INSTALLERLOG
	else
		echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped chown of manager dir" >>$INSTALLERLOG
	fi
####################################################################################################
# Install Completed
####################################################################################################
	echo "\033[40m\033[40;31mFire\033[37mScope\033[33m Agent v$VERSION for $OSNAME has been installed.\n=====================================================================================\n"
	echo "\033[40m\033[40;33m\n\nStarting \033[31mFire\033[37mScope\033[33m Agent $VERSION for $OSNAME\n=====================================================================================\n\033[1m"
	$SHEXE $INIT_DEST/flex_agent start >>$INSTALLERLOG
	$SLEEPEXE 5
	if [ "$SKIPAGENTMANAGER" != "1" ]; then
#		echo "\nStarting FireScope Agent Manager $VERSION for $OSNAME\n========================================================\n"
			echo "\033[40m\033[40;33m\n\nStarting \033[31mFire\033[37mScope\033[33m Agent Manager $VERSION for $OSNAME\n=====================================================================================\n\033[1m"
			sh $INIT_DEST/flex_agent_manager start >>$INSTALLERLOG
		$SLEEPEXE 5
	fi
		echo "\033[40m\033[40;31m\n\nFire\033[37mScope\033[33m Agent v$VERSION for $OSNAME installation and startup complete!!!.\n=====================================================================================\n\n"
		echo "\033[0m" # sets background back to default
exit 0
