#!/bin/bash

# Install script for FireScope Agent for Linux

####################################################################################################
# Variables
####################################################################################################
INSTALLERLOG="/var/tmp/flex_agent_install.log"
VERSION=2.0.11
FSMUSER="root"
FSMGROUP="root"
FSUSER="firescop"
FSGROUP="firescop"
CURDIR=`pwd`
CINAME=`uname -n`
BASEDIR="/opt/firescope"
REQUIRED_VERSION=1.6
APORT="8042"
SPORT="8043"
MPORT="8044"
DACTIVE="0"
UPGRADE="0"
JMX="false"
RMTCMD="1"
REALTIME="1"
STORETIME="300"
STORECOUNT="100"
INIT="/etc/init.d"
INSTALLER="FireScope_flex_agent_Installer.sh"
OSCHK=`cat /etc/*-release`
OSTYPE=`echo $OSTYPE`
OSNAME=$OSTYPE
COPYFROM=""
COPYTO=""
CPUCHK=`uname -i`
DATE=`date` 
WHOAMI=`id | cut -d "(" -f2 | cut -d ")" -f1`
####################################################################################################
# End - Variables
####################################################################################################
####################################################################################################
# functions
####################################################################################################
	
	############################################################################################
	# FireScope Agent Help Function
	############################################################################################
	function show_help () {
		HELPUSAGE="$INSTALLER -A XXX.XXX.XXX.XXX [ options ]"
		HELPAPPLIANCE="-A : Appliance IP or DNS name. Usage FireScope_Agent_Installer.sh -a XXX.XXX.XXX.XXX(Required - IP or DNS Name to FireScope Appliance.)"
		HELPBASEINTALLPATH="-b : InstallPath - Path to install the FireScope Agent. default - /opt/firescope"
		HELPREMOTECOMMAND="-c : RemoteCommand - Allows the FireScope Appliance to send commands to the agent to execute. default 0 (Valid 1 on - 0 off)"
		HELPDISABLEACTIVE="-d : DisableActive - Disables Active checks. default 0 (Valid 1 on - 0 off)"
		HELPHELP="-h : Help - Displays this help file"
		HELPHOSTNAME="-H : CINAME - Hostname or name used to ID the system in the FireScope Appliance. Must match for AgentRemote to work properly."
		HELPJAVAPATH="-j : Path to the Java installation to be used (/usr/java/jre1.6.0_21/bin/java)"
		HELPMANAGERPORT="-m : ManagerPort - Port used by the agent manager to receive data from the FireScope Appliance. default - 8044 (Valid 1-65535)"
		HELPSTORECOUNT="-n : Storecount - Used in Store&Foward mode. The number of metrics stored before sending. default - 100 (valid 10-200)"
		HELPOSTYPE="-o : OS Type - Used to determine how to install the service (Ether use linux-gnu or linux)"
		HELPAGENTPORT="-p : AgentPort - Port used by the agent to receive data from the FireScope Appliance. default - 8042 (Valid 1-65535)"
		HELPREALTIME="-s : Realtime - Sets the FireScope Agent to realtime mode. default - 1 (Valid 1-Realtime 0-Store&Forward)"
		HELPSTORETIME="-t : Storetime - Used in Store&Foward mode. The amount of time in seconds that the agent will cache metrics before sending. default - 300 (Valid 30 - 600)"
		HELPUPGRADE="-u : Upgrade - Used to upgrade a legacy flex_agent.conf to a flex_agent_posix.xml"
		HELPEXAMPLE="e.g. $INSTALLER -A 10.0.2.40 -b /opt/firescope -p 8042 -c 1 -H myserver -s 1 -t 200 -n 400"
		SHOW_HELP="$HELPUSAGE\n\t$HELPAPPLIANCE\n\t$HELPBASEINTALLPATH\n\t$HELPREMOTECOMMAND\n\t$HELPDISABLEACTIVE\n\t$HELPHELP\n\t$HELPHOSTNAME\n\t$HELPMANAGERPORT\n\t$HELPSTORECOUNT\n\t$HELPOSTYPE\n\t$HELPAGENTPORT\n\t$HELPREALTIME\n\t$HELPSTORETIME\n\t$HELPUPGRADE\n\t$HELPEXAMPLE"
		echo -e "$SHOW_HELP"
		exit 1
	}
	############################################################################################
	# Install directory structure function
	############################################################################################
	function install_directories () {
		AGENTDIR="$BASEDIR/agent"
		JAVAPARMS="\" -Djava.library.path=$AGENTDIR/bin/lib -jar \"" 
		MANAGERDIR="$BASEDIR/agent_manager"
		FLEXAGENT_BINS="$CURDIR/firescope/agent/bins/flex_agent"
		REDHAT_32_INIT="$CURDIR/etc/init.d/RedHat"
		REDHAT_64_INIT="$CURDIR/etc/init.d/RedHat"
		SLES10_32_INIT="$CURDIR/etc/init.d/SLES"
		SLES10_64_INIT="$CURDIR/etc/init.d/SLES"
		SLES11_32_INIT="$CURDIR/etc/init.d/SLES"
		SLES11_64_INIT="$CURDIR/etc/init.d/SLES"
		AGENT_PID_FILES="$CURDIR/firescope/agent/logs"
		AGENT_PID_DEST_FILES="$AGENTDIR/logs"
		CONFIGFILE="${AGENTDIR}/conf/flex_agent_posix.xml"
		CONFIGFILEBASE="${AGENTDIR}/conf"
		RELEASENOTESSOURCE="${CURDIR}/ReleaseNotes.txt"
		RELEASENOTESDEST="${AGENTDIR}/docs"
		SCRIPTSSOURCE="${CURDIR}/firescope/agent/scripts"
		SCRIPTSDEST="${AGENTDIR}/scripts"
	}
	############################################################################################
	# End - Agent init sed replace function
	############################################################################################

	############################################################################################
	# Start - sedreplace function 
	############################################################################################
	# Usage
	# sedreplace $1 $2 $3
	# $1 what to search for
	# $2 file to search in
	# $3 line offset in numbers
	# $4 what to replace with
	# e.g. sedreplace "AGENTDIR=AGENTDIR" "$INIT"/flex_agent 0 "AGENTDIR=$AGENTDIR"
	############################################################################################
	function sedreplace () {
		AIModeKey=`grep "$1" "$2" -n | cut -d : -f1`
		echo "AIModeKey=$AIModeKey"  >>$INSTALLERLOG
		let AIModeValue=$AIModeKey+"$3"
		echo "AIModeValue=$AIModeValue"  >>$INSTALLERLOG
		sedLine=`sed $AIModeValue'q;d' $2`
		echo "sedLine=$sedLine"  >>$INSTALLERLOG
		sedLine1=`echo $sedLine` # | cut -d '>' -f2 | cut -d '<' -f1`
		echo "sedLine1=$sedLine1"  >>$INSTALLERLOG
		sedLine2="$4"
		echo "sedLine2=$sedLine2"  >>$INSTALLERLOG
		sed -i -e "$AIModeValue"'s;'"$sedLine1"';'"$sedLine2"';g' $2
	}
	############################################################################################
	# End - sedreplace function
	############################################################################################
	############################################################################################
	# Agent init sed replace function
	############################################################################################
	agent_init_sed () {
		echo "****************************Agent init set agent path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "AGENTDIR=AGENTDIR" "$INIT"/flex_agent 0 "AGENTDIR=$AGENTDIR"
		echo "****************************Agent init set config path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "agentd_cfgfile=agentd_cfgfile" "$INIT/flex_agent" 0 "agentd_cfgfile=$CONFIGFILE"
		echo "****************************Agent init set pid path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "PIDFILE=PIDFILE" "$INIT/flex_agent" 0 "PIDFILE=$AGENTDIR/logs/flex_agent.pid"
		echo "****************************Agent init command 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "FSUSER=FSUSER" "$INIT/flex_agent" 0 "FSUSER=$FSUSER"
		echo "****************************Agent init command 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "JAVAPATH=JAVAPATH" "$INIT/flex_agent" 0 "JAVAPATH=$JAVAPATH"
		echo "****************************Agent init command 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "JAVAPARMS=JAVAPARMS" "$INIT/flex_agent" 0 "JAVAPARMS=$JAVAPARMS"
		echo "****************************Agent init command 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "FLEXAGENT=FLEXAGENT" "$INIT/flex_agent" 0 "FLEXAGENT=$AGENTDIR/bin/flex_agent.jar"
	}
	############################################################################################
	# End - Agent init sed replace function
	############################################################################################
	############################################################################################
	# Agent Manager init sed replace function 
	############################################################################################
	agent_manager_init_sed () {
		echo "****************************Agent manager init set agent path 'Agent Manager init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "MANAGERDIR=MANAGERDIR" "$INIT/flex_agent_manager" 0 "MANAGERDIR=$MANAGERDIR"
		echo "****************************Agent manager init set config path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "agentd_cfgfile=agentd_cfgfile" "$INIT/flex_agent_manager" 0 "agentd_cfgfile=$CONFIGFILE"
		echo "****************************Agent manager init set pid path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "PIDFILE=PIDFILE" "$INIT/flex_agent_manager" 0 "PIDFILE=$AGENTDIR/logs/flex_agent_manager.pid"
		echo "****************************Agent manager init set FSMUSER  'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "FSMUSER=FSMUSER" "$INIT/flex_agent_manager" 0 "FSMUSER=$FSMUSER"
		echo "****************************Agent manager init command 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "JAVAPATH=JAVAPATH" "$INIT/flex_agent_manager" 0 "JAVAPATH=$JAVAPATH"
		echo "****************************Agent manager init command 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "JAVAPARMS=JAVAPARMS" "$INIT/flex_agent_manager" 0 "JAVAPARMS=$JAVAPARMS"
		echo "****************************Agent manager init set manager path 'Agent init sed replace function'***********************" >>$INSTALLERLOG
			sedreplace "FLEXAGENTMANAGER=FLEXAGENTMANAGER" "$INIT/flex_agent_manager" 0 "FLEXAGENTMANAGER=$MANAGERDIR/flex_agent_manager.jar"
	}
	############################################################################################
	# End - Agent Manager init sed replace function
	############################################################################################
####################################################################################################
# copycorefiles function start
####################################################################################################
# Usage
# copycorefiles $1 $2
# $1 OS Bins (i.e. $REDHAT_5_32_BINS, $REDHAT_5_64_BINS, ...)
# $2 INIT Files (i.e. $REDHAT_32_INIT, $REDHAT_64_INIT, ...)
# e.g. copycorefiles
####################################################################################################
function copycorefiles () {
		#------------------------------------------------------------------------------------
		# Copy agent files
		#------------------------------------------------------------------------------------
		echo "Copying $FLEXAGENT_BINS Agent bin" >>$INSTALLERLOG
		cp $FLEXAGENT_BINS/flex_agent.jar $AGENTDIR/bin/flex_agent.jar >>$INSTALLERLOG
		cp -rf $FLEXAGENT_BINS/lib $AGENTDIR/bin/lib >>$INSTALLERLOG
		cp $RELEASENOTESSOURCE $RELEASENOTESDEST >>$INSTALLERLOG
		cp $SCRIPTSSOURCE/oracle.tar $SCRIPTSDEST/oracle.tar >>$INSTALLERLOG
		cp $AGENT_PID_FILES/flex_agent.pid $AGENT_PID_DEST_FILES/ >>$INSTALLERLOG
		#------------------------------------------------------------------------------------
		# Copy agent manager files
		#------------------------------------------------------------------------------------
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			echo "Copying $FLEXAGENT_BINS Agent Manager bins" >>$INSTALLERLOG
			cp $AGENT_PID_FILES/flex_agent_manager.pid $AGENT_PID_DEST_FILES/ >>$INSTALLERLOG
			cp $FLEXAGENT_BINS/flex_agent_manager.jar $MANAGERDIR
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped upgrading manager" >>$INSTALLERLOG
		fi
		#------------------------------------------------------------------------------------
		# Copy agent init files
		#------------------------------------------------------------------------------------
		cp $2/flex_agent $INIT >>$INSTALLERLOG
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			cp $2/flex_agent_manager $INIT >>$INSTALLERLOG
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skippedcopy init manager" >>$INSTALLERLOG
		fi
		#------------------------------------------------------------------------------------
		# Chmod agent init files
		#------------------------------------------------------------------------------------
		chmod +x $INIT/flex_agent >>$INSTALLERLOG
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			chmod +x $INIT/flex_agent_manager >>$INSTALLERLOG
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped chmod manager" >>$INSTALLERLOG
		fi
}
	#############################################################################################
	# End - copycorefiles function
	#############################################################################################
	#############################################################################################
	# init_on_boot function
	#############################################################################################
function init_on_boot () {
if [ "$SKIPAGENTMANAGER" != "1" ]; then
	echo "CPU Check = $CPUCHK" >>$INSTALLERLOG
	echo "Operating System Check = $OSCHK" >>$INSTALLERLOG
	#------------------------------------------------------------------------------------
	# Available Runlevels (RHEL)
	#------------------------------------------------------------------------------------
	# Runlevel		Description
	#------------------------------------------------------------------------------------
	#   0			   Halt
	#   1			   Single-User mode
	#   2			   Multi-user mode console logins only (without networking)
	#  *3			   Multi-User mode, console logins only
	#   4			   Not used/User-definable
	#  *5			   Multi-User mode, with display manager as well as console logins (X11)
	#   6			   Reboot
	#------------------------------------------------------------------------------------
	if [ $OSTYPE == "linux-gnu" ]; then 
		ln -sf /etc/init.d/flex_agent /etc/rc0.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc0.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc1.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc1.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc2.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc2.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc3.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc3.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc4.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc4.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc5.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc5.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc6.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/rc6.d/S50flex_agent

			if [ "$SKIPAGENTMANAGER" != "1" ]; then
				ln -sf /etc/init.d/flex_agent_manager /etc/rc0.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc0.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc1.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc1.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc2.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc2.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc3.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc3.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc4.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc4.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc5.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc5.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc6.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/rc6.d/S50flex_agent_manager
			else
				echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped run levels manager" >>$INSTALLERLOG
			fi
	#------------------------------------------------------------------------------------
	# Available Runlevels (SLES)
	#------------------------------------------------------------------------------------
	# Runlevel		Description
	#------------------------------------------------------------------------------------
	#   0			   Halt
	#   1			   Single-User mode
	#   2			   Multi-User mode without networking
	#  *3			   Multi-User mode, console logins only
	#   4			   Not used/User-definable
	#  *5			   Multi-User mode with display manager
	#   6			   Reboot
	#   S			   Single-User Mode[6]
	#------------------------------------------------------------------------------------
	elif [ $OSTYPE == "linux" ]; then 
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc0.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc0.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc1.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc1.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc2.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc2.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc3.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc3.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc4.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc4.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc5.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc5.d/S50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc6.d/K50flex_agent
		ln -sf /etc/init.d/flex_agent /etc/init.d/rc6.d/S50flex_agent
		insserv flex_agent -n > /dev/null 2>&1

			if [ "$SKIPAGENTMANAGER" != "1" ]; then
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc0.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc0.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc1.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc1.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc2.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc2.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc3.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc3.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc4.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc4.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc5.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc5.d/S50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc6.d/K50flex_agent_manager
				ln -sf /etc/init.d/flex_agent_manager /etc/init.d/rc6.d/S50flex_agent_manager
				insserv flex_agent_manager -n > /dev/null 2>&1
			else
				echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped run levels manager" >>$INSTALLERLOG
			fi
	fi
fi
}
	############################################################################################
	# End - init_on_boot function
	############################################################################################
	############################################################################################
	# checkos function start
	############################################################################################
	# Usage
	# checkos
	# e.g. checkos
	############################################################################################
function checkos () {
	echo "CPU Check = $CPUCHK" >>$INSTALLERLOG
	echo "Operating System Check = $OSCHK" >>$INSTALLERLOG
	sleep 1
	
	if [ $CPUCHK == "x86_64" ]; then 
		if [ `echo $OSCHK | grep -i -c -m1 "Red Hat Enterprise Linux"` == "1" ]; then 
			if [ `echo $OSCHK | grep -i -c -m1 "release 6"` == "1" ]; then 
				OSNAME=`cat /etc/*-release | grep -i -m1 "Red Hat Enterprise Linux"` >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$REDHAT_64_INIT
			else
				OSNAME=`cat /etc/*-release | grep -i -m1 "Red Hat Enterprise Linux"` >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$REDHAT_64_INIT
			fi
		elif [ `echo $OSCHK | grep -i -c -m1 "SUSE Linux Enterprise Server 10"` == "1" ]; then 
				OSNAME=`cat /etc/*-release | grep -i -m1 "SUSE Linux Enterprise Server 10"` >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$SLES10_64_INIT
		elif [ `echo $OSCHK | grep -i -c -m1 "SUSE Linux Enterprise Server 11"` == "1" ]; then 
				OSNAME=`cat /etc/*-release | grep -i -m1 "SUSE Linux Enterprise Server 11"` >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$SLES11_64_INIT
		elif [ `echo $OSCHK | grep -i -c -m1 "CentOS"` == "1" ]; then 
				OSNAME=`cat /etc/*-release | grep -i -m1 "CentOS"` >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$REDHAT_64_INIT
		else
			if [ $OSTYPE == "linux-gnu" ]; then 
				OSNAME=$OSTYPE >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$REDHAT_64_INIT
			elif [ $OSTYPE == "linux" ]; then 
				OSNAME=$OSTYPE >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$SLES10_64_INIT
			else
				echo "Unsupported OS $OSCHK" >>$INSTALLERLOG
				echo "Unsupported OS $OSCHK.  Please use the -o switch for either linux-gnu or linux."
				exit
			fi
		fi
	elif [ $CPUCHK == "i386" ]; then 
	   if [ `echo $OSCHK | grep -i -c -m1 "Red Hat Enterprise Linux"` == "1" ]; then 
	   	   if [ `echo $OSCHK | grep -i -c -m1 "release 6"` == "1" ]; then 
				OSNAME=`cat /etc/*-release | grep -i -m1 "Red Hat Enterprise Linux"` >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$REDHAT_32_INIT
		   else
				OSNAME=`cat /etc/*-release | grep -i -m1 "Red Hat Enterprise Linux"` >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$REDHAT_32_INIT
		   fi
	   elif [ `echo $OSCHK | grep -i -c -m1 "SUSE Linux Enterprise Server 10"` == "1" ]; then 
				OSNAME=`cat /etc/*-release | grep -i -m1 "SUSE Linux Enterprise Server 10"` >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$SLES10_32_INIT
	   elif [ `echo $OSCHK | grep -i -c -m1 "SUSE Linux Enterprise Server 11"` == "1" ]; then 
				OSNAME=`cat /etc/*-release | grep -i -m1 "SUSE Linux Enterprise Server 11"` >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$SLES11_32_INIT
	   elif [ `echo $OSCHK | grep -i -c -m1 "CentOS"` == "1" ]; then 
				OSNAME=`cat /etc/*-release | grep -i -m1 "CentOS"` >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$REDHAT_32_INIT
	   else
			if [ $OSTYPE == "linux-gnu" ]; then 
				OSNAME=$OSTYPE >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$REDHAT_32_INIT
			elif [ $OSTYPE == "linux" ]; then 
				OSNAME=$OSTYPE >>$INSTALLERLOG
				COPYFROM=$FLEXAGENT_BINS
				COPYTO=$SLES10_32_INIT
			else
				echo "Unsupported OS $OSCHK" >>$INSTALLERLOG
				echo "Unsupported OS $OSCHK.  Please use the -o switch for either linux-gnu or linux."
				exit
			fi
	   fi
	else
		echo "Unsupported CPU $CPUCHK" >>$INSTALLERLOG
		echo "Unsupported CPU $CPUCHK"
		exit
   fi
}
	############################################################################################
	# End - checkos function
	############################################################################################
	############################################################################################
	# Uninstaller sed replace function
	############################################################################################
	uninstaller_sed () {
	echo "****************************Agent uninstall dir. 'Uninstaller sed replace function '***************************" >>$INSTALLERLOG
		sedreplace "INIT=INIT" "$AGENTDIR/FireScope_Agent_Uninstall.sh" 0 "INIT=$INIT"
		sedreplace "INSTALLDIR=INSTALLDIR" "$AGENTDIR/FireScope_Agent_Uninstall.sh" 0 "INSTALLDIR=$BASEDIR"
	}
	############################################################################################
	# End - Uninstaller sed replace function
	############################################################################################
################################################################################################
# End - functions
################################################################################################

if [ -f "$INSTALLERLOG" ]; then
	rm -f $INSTALLERLOG
fi
###########################
# FireScope Agent Getopts settings
###########################
install_directories
f="0"
while getopts ":A:a:b:c:d:H:j:K:k:m:n:p:s:t:V:huZ" o
do case $o in
	###########################
	# FireScope Server Set Info
	###########################
	A)
		f="1"
		echo "Checking for connectivity to the FireScope Appliance."
		echo "$DATE == $WHOAMI Passed1FireScopeServerIP=$OPTARG"  >>$INSTALLERLOG

#		if [[ "$OPTARG" =~ "^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])(\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])){3}$" ]]; then
		if [ "$OPTARG" != "" ]; then
			SERVERCHECK=`ping -c 3 $OPTARG | grep -c "3 received"`
			echo "$DATE == $WHOAMI Server Ping Check = ${SERVERCHECK}"  >>$INSTALLERLOG
			echo "Checking for route to Appliance. Please standby."
			if [ ${SERVERCHECK} != "1" ]; then
				echo "Could not ping the FireScope Server!!! Please check IP or DNS and try again."  >>$INSTALLERLOG
			fi
		else
			echo "Invalid IP address, please provide the FireScope appliance IP address."
			echo "$Installer -h more help."
			exit 1
		fi
		SERVER="$OPTARG"
		echo "$DATE == $WHOAMI Set1FireScopeServerIP=${SERVER}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Server Port
	###########################
	a)
		echo "$DATE == $WHOAMI PassedServerPort=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
			SPORT="$OPTARG"
		else
			echo "Server Port (-a) must be between 1 and 65535!!!"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetServerPort=${SPORT}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Path
	###########################
	b)
		echo "$DATE == $WHOAMI Passed2InstallPath=$OPTARG"  >>$INSTALLERLOG
		if [ "$OPTARG" = "" ]; then
			BASEDIR="/opt/firescope"
		elif [ "$OPTARG" != "" ]; then
			BASEDIR="$OPTARG"
			install_directories
		fi
		echo "$DATE == $WHOAMI Set2InstallPath=${BASEDIR}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Server Java Path
	###########################
	j)
		echo "$DATE == $WHOAMI PassedServerPort=$OPTARG"  >>$INSTALLERLOG
		if [ "$OPTARG" = "" ]; then
			echo "Java Home - A path must be supplied with the argument."
			exit 1
		else
			JAVA_HOME="$OPTARG"
		fi
		echo "$DATE == $WHOAMI SetServerPort=${SPORT}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Port
	###########################
	p)
		echo "$DATE == $WHOAMI Passed3Port=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
			APORT="$OPTARG"
		else
			echo "Agent Port (-p) must be between 1 and 65535!!!"
			exit 1
		fi
		echo "$DATE == $WHOAMI Set3Port=${APORT}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Manager Port
	###########################
	m)
		echo "$DATE == $WHOAMI PassedManPort=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
			MPORT="$OPTARG"
		else
			echo "Agent Manager Port (-m) must be between 1 and 65535!!!"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetManPort=${MPORT}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Remote Commands
	###########################
	c)
		echo "$DATE == $WHOAMI PassedRMTCMD=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
			RMTCMD="$OPTARG"
		else
			RMTCMD="0"
			echo "Invalid Argument for Remote commands (-c)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetRMTCMD=${RMTCMD}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Disable Active checks
	###########################
	d)
		echo "$DATE == $WHOAMI PassedDActive=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
			DACTIVE="$OPTARG"
		else
			RMTCMD="0"
			echo "Invalid argument for Disable Active Checks (-d)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetDActive=${DACTIVE}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Hostname
	###########################
	H)
		echo "$DATE == $WHOAMI PassedCINAME=$OPTARG"  >>$INSTALLERLOG
		if [ "$OPTARG" = "" ]; then
			CINAME=`hostname -s`
		fi
		if [ "$OPTARG" != "" ]; then
			CINAME="$OPTARG"
		fi
		echo "$DATE == $WHOAMI SetCINAME=${CINAME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Realtime
	###########################
	s)
		echo "$DATE == $WHOAMI PassedREALTIME=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
			REALTIME="$OPTARG"
		else
			echo "Invaild argument for Agent Realtime mode (-s)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetREALTIME=${REALTIME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Storetime
	###########################
	t)
		echo "$DATE == $WHOAMI PassedSTORETIME=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "29" ] && [ "$OPTARG" -lt "601" ]; then
			STORETIME="$OPTARG"
		else
			echo "Invaild value for Store and Forward time (-t)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetSTORETIME=${STORETIME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent upgrade
	###########################
	u)
		UPGRADE="1"
	;;
	###########################
	# Java Path check
	###########################
	V)
		echo "$DATE == $WHOAMI PassedJVM=$OPTARG"  >>$INSTALLERLOG
		if [ "$OPTARG" = "" ]; then
			JVM=$JAVAPATH
		fi
		if [ "$OPTARG" != "" ]; then
			JVM="$OPTARG"
		fi
		echo "$DATE == $WHOAMI SetJVM=${STORETIME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Storecount
	###########################
	n)
		echo "$DATE == $WHOAMI PassedSTORECOUNT=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "9" ] && [ "$OPTARG" -lt "201" ]; then
			STORECOUNT="$OPTARG"
		else
			echo "Invalid value for Store and Forward Count (-n)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetSTORECOUNT=${STORECOUNT}"  >>$INSTALLERLOG
	;;
	h)
		show_help; exit 0
	;;
	Z)
		SKIPAGENTMANAGER="1"
	;;
	\?)
		echo "Invalid option: -$OPTARG"
		echo "$Installer -h for more help."
		exit 1
	;;
	:)
		echo "Option -$OPTARG requires an argument."
		echo "$Installer -h for more help."
		exit 1
	;;
	esac
done

###########################
# FireScope Check for required flags
###########################
	if [ $UPGRADE -ne "1" ]; then
		if [ "$f" = "0" ]; then 
			echo "The flag -A is required
			$INSTALLER -h for more help"
			exit 1
		elif [ "$1" == "-h" ]; then
			show_help
		elif [ "$1" == "--help" ]; then
			show_help
			exit 0
		fi
	fi
####################################################################################################
#Check if user is root
####################################################################################################
	if [ "${WHOAMI}" != "root" ]; then
		echo "Sorry, root required to install agent."
		exit 1
	fi
####################################################################################################
#End Check if user is root
####################################################################################################
echo -e "\033[40m\033[40;33m" #sets back gound to black
####################################################################################################
#checks if there is a service account on system
####################################################################################################
	#################################
	#Begin Check
	#################################
		#Required Variables
		#################################
		# FSUSER
		# FSGROUP
		#################################
	checkos
	echo "Service account check for Agent" 2>&1 >>$INSTALLERLOG
	IDTEST="`id -un $FSUSER  2>>$INSTALLERLOG`"
	echo "IDTEST=$IDTEST" 2>&1 >>$INSTALLERLOG
	GRPTEST="`cat /etc/group | grep -woz $FSGROUP: | grep -wo $FSGROUP  2>>$INSTALLERLOG`"
	echo "GRPTEST=$GRPTEST"  2>&1 >>$INSTALLERLOG
	COUNTER=0
	if [ -z "$IDTEST" ]; then
		echo "Creating Service Account: $FSUSER"  2>&1 >>$INSTALLERLOG
		`useradd -Mr $FSUSER 2>&1 >>$INSTALLERLOG`
		echo "`id $FSUSER  &>$INSTALLERLOG`" 
		if [ -z "$GRPTEST" ]; then
			echo "Creating Service Group: $FSGROUP"  2>&1 >>$INSTALLERLOG
			`groupadd -r $FSGROUP 2>>$INSTALLERLOG`
		fi
	else
		echo "User and Groups exist, Upgrading Agent Installation...."  2>&1 >>$INSTALLERLOG
	fi
####################################################################################################
#checks if there is a service account for Agent Manager on system
####################################################################################################
	#Begin Check
	#################################
		#Required Variables
		#################################
		# USER
		# GROUP
		#################################
	echo "Service account check for Agent Manager" >>$INSTALLERLOG
	IDTEST2="`id -un $FSMUSER 2>>$INSTALLERLOG`"
	echo "IDTEST2=$IDTEST2" >>$INSTALLERLOG
	GRPTEST2="`cat /etc/group | grep -woz $FSMGROUP: | grep -wo $FSMGROUP 2>>$INSTALLERLOG`"
	echo "GRPTEST2=$GRPTEST2" 2>&1 >>$INSTALLERLOG
	COUNTER=0
	if [ -z "$IDTEST2" ]; then
		echo "Creating Service Account: $FSUSER"  2>&1 >>$INSTALLERLOG
		`useradd -Mr $FSMUSER 2>>$INSTALLERLOG`
		echo "`id $FSMUSER 2>&1 >>$INSTALLERLOG`"
		if [ -z "$GRPTEST2" ]; then
			echo "Creating Service Group: $FSMGROUP"  2>&1 >>$INSTALLERLOG
			`groupadd -r $FSMGROUP 2>&1 >>$INSTALLERLOG`
		fi
	fi
####################################################################################################
# Service running checks
####################################################################################################
	AGENTSERVICE=`pidof flex_agent` 2>&1 >>$INSTALLERLOG

	if [ "$AGENTSERVICE" != "" ]; then
		sh /etc/init.d/flex_agent stop  2>&1 >>$INSTALLERLOG
		echo "sent service stop for Agent"  2>&1 >>$INSTALLERLOG
		echo "pid = $AGENTSERVICE"  2>&1 >>$INSTALLERLOG
	else 
		AGENTSERVICE=`ps -aef | grep $AGENTDIR/bin/flex_agent | grep -v grep | grep -v start | awk '{print $2}'` >>$INSTALLERLOG
		if [ "$AGENTSERVICE" != "" ]; then
			sh /etc/init.d/flex_agent stop  2>&1 >>$INSTALLERLOG
			echo "sent service stop for Agent"  2>&1 >>$INSTALLERLOG
			echo "pid = $AGENTSERVICE"  2>&1 >>$INSTALLERLOG
		else
			echo "Agent was not running, Installing!"  2>&1 >>$INSTALLERLOG
		fi
	fi

	if [ "$SKIPAGENTMANAGER" != "1" ]; then
		AGENTMANAGERSERVICE=`pidof flex_agent_manager` 2>&1 >>$INSTALLERLOG
		
		if [ "$AGENTMANAGERSERVICE" != "" ]; then
			sh /etc/init.d/flex_agent_manager stop  2>&1 >>$INSTALLERLOG
			echo "sent service stop for Agent Manager"  2>&1 >>$INSTALLERLOG
			echo "pid = $AGENTMANAGERSERVICE" 2>&1 >>$INSTALLERLOG
		else  
			AGENTMANAGERSERVICE=`ps -aef | grep $MANAGERDIR/flex_agent_manager | grep -v grep | grep -v start | awk '{print $2}'` >>$INSTALLERLOG
			if [ "$AGENTMANAGERSERVICE" != "" ]; then
				sh /etc/init.d/flex_agent_manager stop  2>&1 >>$INSTALLERLOG
				echo "sent service stop for Agent Manager"  2>&1 >>$INSTALLERLOG
				echo "pid = $AGENTMANAGERSERVICE" 2>&1 >>$INSTALLERLOG
			else
				echo "Agent Manager was not running, Installing" 2>&1 >>$INSTALLERLOG
			fi
		fi
	fi
####################################################################################################
################################
#End Check
################################
	echo "creating dir structure" >>$INSTALLERLOG
	mkdir -p $BASEDIR >>$INSTALLERLOG
	mkdir -p $AGENTDIR >>$INSTALLERLOG
	mkdir -p $AGENTDIR/bin >>$INSTALLERLOG
	mkdir -p $AGENTDIR/.agent >>$INSTALLERLOG
	mkdir -p $AGENTDIR/cache >>$INSTALLERLOG
	mkdir -p $AGENTDIR/conf >>$INSTALLERLOG
	mkdir -p $AGENTDIR/logs >>$INSTALLERLOG
	mkdir -p $AGENTDIR/scripts >>$INSTALLERLOG
	mkdir -p $AGENTDIR/backup >>$INSTALLERLOG
	if [ "$SKIPAGENTMANAGER" != "1" ]; then	
		mkdir -p $MANAGERDIR >>$INSTALLERLOG
		mkdir -p $MANAGERDIR/.agent_manager >>$INSTALLERLOG
		mkdir -p $MANAGERDIR/temp >>$INSTALLERLOG
	else
		echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped mkdir of manager" >>$INSTALLERLOG
	fi

################################
# Echo to $INSTALLERLOG
################################

	echo "$DATE == $WHOAMI mkdir Variables" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI BASEDIR=$BASEDIR" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR=$AGENTDIR" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/bin-$AGENTDIR/bin" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/.agent=$AGENTDIR/.agent" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/cache=$AGENTDIR/cache" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/conf=$AGENTDIR/conf" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/logs=$AGENTDIR/logs" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/scripts=$AGENTDIR/scripts" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/backup=$AGENTDIR/backup" >>$INSTALLERLOG
	if [ "$SKIPAGENTMANAGER" != "1" ]; then	
		echo "$DATE == $WHOAMI MANAGERDIR=$MANAGERDIR" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI MANAGERDIR/.agent_manager=$MANAGERDIR/.agent_manager" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI MANAGERDIR/temp=$MANAGERDIR/temp" >>$INSTALLERLOG
	else
		echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped echo of manager" >>$INSTALLERLOG
	fi

################################
# Echo to $MANAGERDIR/.agent_manager/agent_paths
################################

	echo "$DATE == $WHOAMI mkdir Variables" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI BASEDIR=$BASEDIR" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR=$AGENTDIR" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/bin-$AGENTDIR/bin" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/.agent=$AGENTDIR/.agent" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/cache=$AGENTDIR/cache" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/conf=$AGENTDIR/conf" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/logs=$AGENTDIR/logs" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/scripts=$AGENTDIR/scripts" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/backup=$AGENTDIR/backup" >>$MANAGERDIR/.agent_manager/agent_paths
	if [ "$SKIPAGENTMANAGER" != "1" ]; then	
		echo "$DATE == $WHOAMI MANAGERDIR=$MANAGERDIR" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI MANAGERDIR/.agent_manager=$MANAGERDIR/.agent_manager" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI MANAGERDIR/temp=$MANAGERDIR/temp" >>$MANAGERDIR/.agent_manager/agent_paths
	else
		echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped agent paths of manager" >>$INSTALLERLOG
	fi
############################		
# Presentation
############################
	echo -e "\033[40m\033[40;31m\n\nFire\033[37mScope\033[33m Agent $VERSION Installer for $OSNAME\n=====================================================================================\n"
####################################################################################################
# Check Java Version
####################################################################################################
# Transform the required version string into a number that can be used in comparisons
REQUIRED_VERSION=`echo $REQUIRED_VERSION | sed -e 's;\.;0;g'`
# Check JAVA_HOME directory to see if Java version is adequate
#if [ -z "$JAVA_HOME" ]; then
#	echo "Installation Stopped!! Java $JAVA_VERSION is not $REQUIRED_VERSION or higher.\n=====================================================================================\n\n"
#	echo -e "\033[0m" # sets background back to default
#	exit 0
#else
#	echo -e "\033[40m\033[40;31m\n\nFire\033[37mScope\033[33m Agent v$VERSION for $OSNAME Checking Java Version...\n=====================================================================================\n\n"
#fi

if [ $JAVA_HOME ]
then
	JAVA_EXE=$JAVA_HOME/bin/java
	$JAVA_EXE -version 2> tmp.ver
	JAVA_VERSION=`cat tmp.ver | grep "java version" | awk '{ print substr($3, 2, length($3)-2); }'`
	rm tmp.ver
	JAVA_VERSION=`echo $JAVA_VERSION | awk '{ print substr($1, 1, 3); }' | sed -e 's;\.;0;g'`
	if [ $VERSION ]
	then
		if [ $JAVA_VERSION -ge $REQUIRED_VERSION ]
		then
			JAVA_HOME=`echo $JAVA_EXE | awk '{ print substr($1, 1, length($1)-9); }'`
		else
			JAVA_HOME=
		fi
	else
		JAVA_HOME=
	fi
fi

# If the existing JAVA_HOME directory is adequate, then leave it alone
# otherwise, use 'find' to search for other possible java candidates and
# check their versions.
if [ $JAVA_HOME ]
then
	:
else
	for JAVA_EXE in `find /usr -name java | grep bin/java$ | xargs echo`
	do
		if [ $JAVA_HOME ] 
		then
			:
		else
			$JAVA_EXE -version 2> tmp.ver 1> /dev/null
			JAVA_VERSION=`cat tmp.ver | grep "java version" | awk '{ print substr($3, 2, length($3)-2); }'`
			rm tmp.ver
			JAVA_VERSION=`echo $JAVA_VERSION | awk '{ print substr($1, 1, 3); }' | sed -e 's;\.;0;g'`
			if [ $JAVA_VERSION ]
			then
				if [ $JAVA_VERSION -ge $REQUIRED_VERSION ]
				then
					JAVA_HOME=`echo $JAVA_EXE | awk '{ print substr($1, 1, length($1)-9); }'`
				fi
			fi
		fi
	done
fi

# If the correct Java version is detected, then export the JAVA_HOME environment variable
if [ $JAVA_HOME ]
then
	export JAVA_HOME
	JAVAPATH="$JAVA_HOME/bin/java"
	echo "JAVAPATH=$JAVAPATH" >>$INSTALLERLOG
	echo $JAVA_HOME >>$INSTALLERLOG
	#echo $JAVA_HOME >> $INSTALLERLOG
else
	echo "Installation Stopped!!! Java $JAVA_VERSION is not $REQUIRED_VERSION or higher."
	echo "Please set the JAVA_HOME directory or supply the path to java using the -j <path> switch."
	echo "==========================================================================================="
	echo -e "\033[0m" # sets background back to default
	exit 0
fi

####################################################################################################
# Copy core files
####################################################################################################
	copycorefiles $COPYFROM $COPYTO
	echo "Copying Linux Agent Uninstaller script" >>$INSTALLERLOG
	cp $CURDIR/firescope/agent/FireScope_Agent_Uninstall.sh $AGENTDIR/FireScope_Agent_Uninstall.sh >>$INSTALLERLOG
####################################################################################################
# End - Copy core files
####################################################################################################

####################################################################################################
# chmod agent and agent manager bins
####################################################################################################
		chmod +x $AGENTDIR/FireScope_Agent_Uninstall.sh >>$INSTALLERLOG
		chmod +x $AGENTDIR/bin/flex_agent.jar >>$INSTALLERLOG
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			chmod +x $MANAGERDIR/flex_agent_manager.jar >>$INSTALLERLOG
		fi
####################################################################################################
# End - chmod agent and agent manager bins
####################################################################################################
####################################################################################################
# Set some user input and collected values in config file
####################################################################################################
	###############################################
	# check for .conf and convert
	###############################################
		if [ -f $CONFIGFILEBASE/flex_agent.conf ]; then
			echo "### Conf upgrade conf --> xml ###" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent.conf -u "" >>$INSTALLERLOG
					echo 'Upgrading conf--->xml $AGENTDIR/bin/flex_agent -c $CONFIGFILEBASE/flex_agent.conf -u ""' >>$INSTALLERLOG
					echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
	###############################################
	# check for .xml and convert
	###############################################
	elif [ -f $CONFIGFILEBASE/flex_agent_posix.xml ]; then >>$INSTALLERLOG
		echo "### Conf upgrade xml --> xml ###"  >>$INSTALLERLOG
			$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "" >>$INSTALLERLOG
				 echo 'Upgrading xml--->xml $AGENTDIR/bin/flex_agent -c $CONFIGFILEBASE/flex_agent_posix.xml -u ""' >>$INSTALLERLOG
				 echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
	###############################################
	# create new config xml file
	###############################################
	else
		echo "### New Config XML Created ###" >>$INSTALLERLOG
		####################################################################################
		# New Config xml created
		####################################################################################
			echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
			echo "Building new xml $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent.conf -u AgentServiceName=flex_agent|AgentServiceStart=service flex_agent start|AgentServiceStop=service flex_agent stop" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "AgentServiceName=flex_agent|AgentServiceStart=service flex_agent start|AgentServiceStop=service flex_agent stop" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u ListenIP=0.0.0.0|ManagerIP=|Server=$SERVER|ServerPort=$SPORT|Hostname=$CINAME|EnableRemoteCommands=$RMTCMD|DisableActive=$DACTIVE" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "ListenIP=0.0.0.0|ManagerIP=|Server=$SERVER|ServerPort=$SPORT|Hostname=$CINAME|EnableRemoteCommands=$RMTCMD|DisableActive=$DACTIVE" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u ListenPort=$APORT|TempFileLocation=$AGENTDIR/cache|LogFile=$AGENTDIR/logs/flex_agent.log|PidFile=$AGENTDIR/logs/flex_agent.pid" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "ListenPort=$APORT|TempFileLocation=$AGENTDIR/cache|LogFile=$AGENTDIR/logs/flex_agent.log|PidFile=$AGENTDIR/logs/flex_agent.pid" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u AgentImmediateMode=$REALTIME|AgentStoreDurationSeconds=$STORETIME|AgentStoreCount=$STORECOUNT" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "AgentImmediateMode=$REALTIME|AgentStoreDurationSeconds=$STORETIME|AgentStoreCount=$STORECOUNT" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u ManagerPort=$MPORT|ManagerInstallationRoot=$MANAGERDIR|ManagerLogFile=$AGENTDIR/logs/flex_agent_manager.log|ManagerPidFile=$AGENTDIR/logs/flex_agent_manager.pid|ManagerIp=0.0.0.0" >>$INSTALLERLOG
				$JAVAPATH -Djava.library.path=$AGENTDIR/bin/lib -jar $AGENTDIR/bin/flex_agent.jar -c $CONFIGFILEBASE/flex_agent_posix.xml -u "ManagerPort=$MPORT|ManagerInstallationRoot=$MANAGERDIR|ManagerLogFile=$AGENTDIR/logs/flex_agent_manager.log|ManagerPidFile=$AGENTDIR/logs/flex_agent_manager.pid|ManagerIp=0.0.0.0" >>$INSTALLERLOG
	fi
		####################################################################################
		# Start - agent_init_sed
		####################################################################################
			uninstaller_sed
		####################################################################################
		# End - agent_init_sed
		####################################################################################

		####################################################################################
		# Start - agent_init_sed
		####################################################################################
			agent_init_sed
		####################################################################################
		# End - agent_init_sed
		####################################################################################

		####################################################################################
		# Start - agent_manager_init_sed
		####################################################################################
			if [ "$SKIPAGENTMANAGER" != "1" ]; then
				agent_manager_init_sed >>$INSTALLERLOG
			else
				echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER agent_manager_init_sed" >>$INSTALLERLOG
			fi
		####################################################################################
		# End - agent_manager_init_sed
		####################################################################################

####################################################################################################
# End - Set some user input and collected values in config file
####################################################################################################
####################################################################################################
# Copy agent version file
####################################################################################################
	echo "$INSTALLER" > $AGENTDIR/.agent/flex_agent_version
	if [ "$SKIPAGENTMANAGER" != "1" ]; then
		echo "$VERSION" > $MANAGERDIR/.agent_manager/flex-agent_manager_version
	fi
####################################################################################################
# Chown the firescope directory and all child directory to be owned by firescop
####################################################################################################
	chown -R $FSUSER:$FSGROUP $BASEDIR >>$INSTALLERLOG
	if [ "$SKIPAGENTMANAGER" != "1" ]; then
		chown -R $FSMUSER:$FSMGROUP $MANAGERDIR >>$INSTALLERLOG
	else
		echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped chown of manager dir" >>$INSTALLERLOG
	fi
####################################################################################################
# Start - init_on_boot
####################################################################################################
init_on_boot
####################################################################################################
# End - init_on_boot
####################################################################################################
####################################################################################################
# Install Completed
####################################################################################################
	echo -e "\033[40m\033[40;31mFire\033[37mScope\033[33m Agent v$VERSION for $OSNAME has been installed.\n=====================================================================================\n"
	echo -e "\033[40m\033[40;33m\n\nStarting \033[31mFire\033[37mScope\033[33m Agent $VERSION for $OSNAME\n=====================================================================================\n\033[1m"
	/bin/sh /etc/init.d/flex_agent start
	sleep 5
	if [ "$SKIPAGENTMANAGER" != "1" ]; then
#		echo -e "\nStarting FireScope Agent Manager $VERSION for $OSNAME\n========================================================\n"
			echo -e "\033[40m\033[40;33m\n\nStarting \033[31mFire\033[37mScope\033[33m Agent Manager $VERSION for $OSNAME\n=====================================================================================\n\033[1m"
			sh /etc/init.d/flex_agent_manager start >>$INSTALLERLOG
		sleep 5
	fi
		echo -e "\033[40m\033[40;31m\n\nFire\033[37mScope\033[33m Agent v$VERSION for $OSNAME installation and startup complete!!!.\n=====================================================================================\n\n"
		echo -e "\033[0m" # sets background back to default
exit 0
